@@ -8,6 +8,7 @@ $options = array
     'login'    => SOLR_SERVER_USERNAME,
     'password' => SOLR_SERVER_PASSWORD,
     'port'     => SOLR_SERVER_PORT,
+    'path'     => SOLR_SERVER_PATH,
 );
 
 $client = new SolrClient($options);
@@ -22,5 +23,3 @@ $doc->addField('cat', 'Lucene');
 $updateResponse = $client->addDocument($doc,false,1000);
 
 print_r($updateResponse->getResponse());
-
-?>
