@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2014 The PHP Group                                |
+   | Copyright (c) 1997-2015 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -48,6 +48,7 @@ static void solr_client_init_urls(solr_client_t *solr_client)
 	solr_string_free(&(options->ping_url));
 	solr_string_free(&(options->terms_url));
 	solr_string_free(&(options->system_url));
+	solr_string_free(&(options->get_url));
 
 	/* Making http://hostname:host_port/path/ */
 
@@ -74,6 +75,7 @@ static void solr_client_init_urls(solr_client_t *solr_client)
 	solr_string_append_solr_string(&(options->ping_url),   &url_prefix);
 	solr_string_append_solr_string(&(options->terms_url),  &url_prefix);
 	solr_string_append_solr_string(&(options->system_url),  &url_prefix);
+	solr_string_append_solr_string(&(options->get_url),  &url_prefix);
 
 	/* Making http://hostname:host_port/path/servlet/ */
 	solr_string_append_solr_string(&(options->update_url), &(options->update_servlet));
@@ -82,6 +84,7 @@ static void solr_client_init_urls(solr_client_t *solr_client)
 	solr_string_append_solr_string(&(options->ping_url),   &(options->ping_servlet));
 	solr_string_append_solr_string(&(options->terms_url),  &(options->terms_servlet));
 	solr_string_append_solr_string(&(options->system_url),  &(options->system_servlet));
+	solr_string_append_solr_string(&(options->get_url), &(options->get_servlet));
 
 	solr_string_append_const(&(options->update_url), "/?version=2.2&indent=on&wt=");
 	solr_string_append_const(&(options->search_url), "/?version=2.2&indent=on&wt=");
@@ -89,6 +92,7 @@ static void solr_client_init_urls(solr_client_t *solr_client)
 	solr_string_append_const(&(options->ping_url),   "/?version=2.2&indent=on&wt=");
 	solr_string_append_const(&(options->terms_url),  "/?version=2.2&indent=on&wt=");
 	solr_string_append_const(&(options->system_url),  "/?version=2.2&indent=on&wt=");
+	solr_string_append_const(&(options->get_url),  "/?version=2.2&indent=on&wt=");
 
 	solr_string_append_solr_string(&(options->update_url), &(options->response_writer));
 	solr_string_append_solr_string(&(options->search_url), &(options->response_writer));
@@ -96,6 +100,7 @@ static void solr_client_init_urls(solr_client_t *solr_client)
 	solr_string_append_solr_string(&(options->ping_url),   &(options->response_writer));
 	solr_string_append_solr_string(&(options->terms_url),  &(options->response_writer));
 	solr_string_append_solr_string(&(options->system_url),  &(options->response_writer));
+	solr_string_append_solr_string(&(options->get_url),  &(options->response_writer));
 
 	solr_string_free(&url_prefix);
 }
@@ -279,6 +284,7 @@ PHP_METHOD(SolrClient, __construct)
 	solr_string_append_const(&(client_options->ping_servlet),   SOLR_DEFAULT_PING_SERVLET);
 	solr_string_append_const(&(client_options->terms_servlet),  SOLR_DEFAULT_TERMS_SERVLET);
 	solr_string_append_const(&(client_options->system_servlet),  SOLR_DEFAULT_SYSTEM_SERVLET);
+	solr_string_append_const(&(client_options->get_servlet), SOLR_DEFAULT_GET_SERVLET);
 
 
 	if (zend_hash_find(options_ht, "wt", sizeof("wt"), (void**) &tmp1) == SUCCESS && Z_TYPE_PP(tmp1) == IS_STRING && Z_STRLEN_PP(tmp1))
@@ -1345,6 +1351,128 @@ PHP_METHOD(SolrClient, deleteByQuery)
 }
 /* }}} */
 
+/* {{{ proto SolrQueryResponse SolrClient::getById(string id)
+   Get Document By Id. Utilizes Solr Realtime Get (RTG) */
+PHP_METHOD(SolrClient, getById)
+{
+    solr_client_t *client;
+    solr_char_t *id;
+    size_t id_len = 0;
+    solr_string_t query_string;
+    int success = 1;
+
+    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &id, &id_len) == FAILURE)
+    {
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid parameter");
+        return;
+    }
+
+    if (solr_fetch_client_entry(getThis(), &client TSRMLS_CC) == FAILURE)
+    {
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid parameter");
+        return;
+    }
+    /* Always reset the URLs before making any request */
+    solr_client_init_urls(client);
+
+    solr_string_init(&query_string);
+    solr_string_appends(&query_string, "id=", sizeof("id=")-1);
+    solr_string_appends(&query_string, id, id_len);
+
+    solr_string_append_solr_string(&(client->handle.request_body.buffer), &query_string);
+    if (solr_make_request(client, SOLR_REQUEST_GET TSRMLS_CC) == FAILURE)
+    {
+        /* if there was an error with the http request solr_make_request throws an exception by itself
+         * if it wasn't a curl connection error, throw exception (omars)
+         */
+        HANDLE_SOLR_SERVER_ERROR(client,"get");
+        success = 0;
+    }
+
+    if (return_value_used) {
+        object_init_ex(return_value, solr_ce_SolrQueryResponse);
+        solr_set_response_object_properties(solr_ce_SolrQueryResponse, return_value, client, &(client->options.get_url), success TSRMLS_CC);
+    }
+    solr_string_free(&query_string);
+}
+/* }}} */
+
+/* {{{ proto SolrQueryResponse SolrClient::getByIds(array ids)
+   Get Documents By Ids. Utilizes Solr Realtime Get (RTG) */
+PHP_METHOD(SolrClient, getByIds)
+{
+    solr_client_t *client;
+    HashTable *ids = NULL;
+    zval *ids_z = NULL;
+    zend_bool invalid_param = 0;
+    solr_string_t query_string;
+    size_t current_position = 0;
+    int success = 1;
+
+    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "a", &ids_z) == FAILURE)
+    {
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid parameter");
+        return;
+    }
+
+    if (solr_fetch_client_entry(getThis(), &client TSRMLS_CC) == FAILURE)
+    {
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "Internal Error: Cannot fetch client object");
+        return;
+    }
+    ids = Z_ARRVAL_P(ids_z);
+    if (ids->nNumOfElements < 1)
+    {
+        solr_throw_exception_ex(solr_ce_SolrIllegalArgumentException, 4000 TSRMLS_CC, SOLR_FILE_LINE_FUNC, "Invalid parameter: at least 1 ID is required. Passed an empty array.", current_position);
+    }
+    /* Always reset the URLs before making any request */
+    solr_client_init_urls(client);
+
+    solr_string_init(&query_string);
+    solr_string_appends(&query_string, "ids=", sizeof("ids=")-1);
+    SOLR_HASHTABLE_FOR_LOOP(ids)
+    {
+        zval **id_zv = NULL;
+        zend_hash_get_current_data(ids, (void **) &id_zv);
+        if (Z_TYPE_PP(id_zv) == IS_STRING && Z_STRLEN_PP(id_zv)) {
+            solr_string_appends(&query_string, Z_STRVAL_PP(id_zv), Z_STRLEN_PP(id_zv));
+            solr_string_appendc(&query_string, ',');
+        } else {
+            invalid_param = 1;
+            goto solr_getbyids_exit;
+        }
+        current_position++;
+    }
+
+
+
+solr_getbyids_exit:
+    if (invalid_param) {
+        solr_string_free(&query_string);
+        solr_throw_exception_ex(solr_ce_SolrIllegalArgumentException, 4000 TSRMLS_CC, SOLR_FILE_LINE_FUNC, "Invalid id at position %ld", current_position);
+        return;
+    }
+    solr_string_remove_last_char(&query_string);
+
+    solr_string_append_solr_string(&(client->handle.request_body.buffer), &query_string);
+    if (solr_make_request(client, SOLR_REQUEST_GET TSRMLS_CC) == FAILURE)
+    {
+        /* if there was an error with the http request solr_make_request throws an exception by itself
+         * if it wasn't a curl connection error, throw exception (omars)
+         */
+
+        HANDLE_SOLR_SERVER_ERROR(client,"get");
+        success = 0;
+    }
+
+    if (return_value_used) {
+        object_init_ex(return_value, solr_ce_SolrQueryResponse);
+        solr_set_response_object_properties(solr_ce_SolrQueryResponse, return_value, client, &(client->options.get_url), success TSRMLS_CC);
+    }
+    solr_string_set_ex(&(client->handle.request_body.buffer),(solr_char_t *)0x00, 0);
+    solr_string_free(&query_string);
+}
+/* }}} */
 
 /* {{{ proto void SolrClient::setResponseWriter(string responseWriter)
    Allows the user to specify which response writer to use */
